@@ -13,22 +13,21 @@
 // limitations under the License.
 
 mod btree;
+#[cfg(feature = "database-lmdb")]
 mod lmdb;
-#[cfg(feature = "state-merkle-redis-db-tests")]
-mod redisdb;
 #[cfg(feature = "state-merkle-sql-postgres-tests")]
 mod sql_postgres;
 #[cfg(all(feature = "state-merkle-sql", feature = "sqlite"))]
 mod sql_sqlite;
-#[cfg(feature = "sqlite-db")]
+#[cfg(feature = "database-sqlite")]
 mod sqlitedb;
 
 use std::collections::HashMap;
 use std::str::from_utf8;
 
-use protobuf::Message as _;
 use rand::seq::IteratorRandom;
 use rand::thread_rng;
+use sha2::{Digest, Sha512};
 
 use transact::{
     database::{error::DatabaseError, Database},
@@ -93,7 +92,7 @@ fn test_merkle_trie_root_advance(db: Box<dyn Database>) {
             .index_get(CHANGE_LOG_INDEX, new_root_bytes)
             .expect("A database error occurred")
             .expect("Did not return a change log entry");
-        ChangeLogEntry::parse_from_bytes(entry_bytes).expect("Failed to parse change log entry")
+        protobuf::Message::parse_from_bytes(entry_bytes).expect("Failed to parse change log entry")
     };
 
     assert_eq!(orig_root_bytes, &change_log.parent);
@@ -1324,7 +1323,7 @@ fn assert_read_value_at_address<R>(
 
 fn expect_change_log(db: &dyn Database, root_hash: &[u8]) -> ChangeLogEntry {
     let reader = db.get_reader().unwrap();
-    ChangeLogEntry::parse_from_bytes(
+    protobuf::Message::parse_from_bytes(
         &reader
             .index_get(CHANGE_LOG_INDEX, root_hash)
             .expect("No db errors")
@@ -1354,8 +1353,9 @@ fn assert_has_successors(change_log: &ChangeLogEntry, successor_roots: &[&[u8]])
 }
 
 fn hex_hash(input: &[u8]) -> String {
-    let mut bytes: Vec<u8> = Vec::new();
-    bytes.extend(openssl::sha::sha512(input).iter());
+    let mut hasher = Sha512::new();
+    hasher.update(input);
+    let bytes = hasher.finalize().to_vec();
     let (hash, _rest) = bytes.split_at(bytes.len() / 2);
     hex::encode(hash.to_vec())
 }
